repoproviders
=============

Module: :mod:`binderhub.repoproviders`
--------------------------------------

.. automodule:: binderhub.repoproviders

.. currentmodule:: binderhub.repoproviders

:class:`RepoProvider`
---------------------

.. autoconfigurable:: RepoProvider
    :members:

:class:`GitHubRepoProvider`
---------------------------

.. autoconfigurable:: GitHubRepoProvider
    :members:
